import afloat.time as time
# import afloat.sfodautils.harmonic_analysis as harmonic_analysis  
from afloat.sfodautils import harmonic_analysis as sha
import afloat.timeseries as timeseries
import afloat.clean as clean

from afloat import currents
from afloat import pca
from afloat import shape
from afloat import netcdf
from afloat import xr
from afloat import config
# from afloat import xrwrap
# from afloat import operational